@@ -123,6 +123,14 @@ sorted_classifiers = [
     "Framework :: Matplotlib",
     "Framework :: Nengo",
     "Framework :: Odoo",
+    "Framework :: Odoo :: 8.0",
+    "Framework :: Odoo :: 9.0",
+    "Framework :: Odoo :: 10.0",
+    "Framework :: Odoo :: 11.0",
+    "Framework :: Odoo :: 12.0",
+    "Framework :: Odoo :: 13.0",
+    "Framework :: Odoo :: 14.0",
+    "Framework :: Odoo :: 15.0",
     "Framework :: Opps",
     "Framework :: Paste",
     "Framework :: Pelican",
@@ -439,6 +447,7 @@ sorted_classifiers = [
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
     "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: 3.11",
     "Programming Language :: Python :: Implementation",
     "Programming Language :: Python :: Implementation :: CPython",
     "Programming Language :: Python :: Implementation :: IronPython",
